# aplicação que mostra a distribuição normal sobreposta à distribuição Binomial
#
# autor: Sergio Miranda Freire (Universidade do Estado do Rio de Janeiro)
# 
# License: Creative Commons: CC BY-SA
#

library(shiny)
library(RcmdrMisc)
resolution <- 0.1

server <- function(input, output) {
  
    # número de experimento de Bernouilli
    n <- reactive ({
        input$n
    })
    
    # probabilidade de sucesso em um experimento de Bernouilli
    p <- reactive ({
        input$p
    })
    
    # média da distribuição binomial
    mean <- reactive ({
        n() * p()
    })

    # desvio padrão da distribuição binomial
    sd_ <- reactive ({
        sqrt(n() * p() * (1 - p()))
    })
    
    # plota os gráficos da distribuição binomial e da normal com mesma média e desvio padrão
    output$binomial_normal <- renderPlot({
        .x <- 0:n()
        plotDistr(.x, dbinom(.x, size = n(), prob = p()), ylim = c(0, dnorm(mean(), mean(), sd_())),
            xlab = "Número de Sucessos", ylab = "Distribuição de Probabilidades",
            main = paste("Distribuição Binomial:  np = ", sprintf("%.1f", mean()), "    n x (1-p) = ", sprintf("%.1f", n() * (1-p())), sep=""),
            discrete = TRUE
        )
        curve(dnorm(x, mean(), sd_()), xlim = c(0, n()), main = "", xlab = "", ylab = "", yaxt = 'n', 
          ylim = c(0, dnorm(mean(), mean(), sd_())), add = TRUE, col = "blue"
        )
    })
}

 
ui <- fluidPage(
    titlePanel("Binomial x Normal"),
    
    sidebarLayout(sidebarPanel(
        sliderInput("n", label = expression("Número de experimentos"), min = 5, max = 1000, value = 10),
        sliderInput("p", label = "probabilidade de sucesso", min = 0.0001, max = 1, value = 0.5)
),
    
    # Show plots
    mainPanel(plotOutput("binomial_normal")))
)

shinyApp(ui = ui, server = server)