# aplicação que mostra a distribuição normal sobreposta à distribuição de Poisson
#
# autor: Sergio Miranda Freire (Universidade do Estado do Rio de Janeiro)
# 
# License: Creative Commons: CC BY-SA
#

library(shiny)
library(RcmdrMisc)

server <- function(input, output) {

    # parâmetro da distribuição de Poisson
    lambda <- reactive ({
        input$lambda
    })
    
    # desvio padrão da distribuição de Poisson
    sd_ <- reactive ({
        sqrt(lambda())
    })
    
    # plota os gráficos da distribuição binomial e da normal com mesma média e desvio padrão
    output$poisson_normal <- renderPlot({
      # dependendo do parâmetro da distribuição de Poisson, seleciona o número máximo de ocorrências 
      # cujas probabilidades serão plotadas
      if (lambda() < 4) {
          .x <- 0:trunc(lambda() * 5)
      } else {
          .x <- 0:trunc(lambda() * 2.5)
      }
      # gráfico da distribuição de Poisson
      plotDistr(.x, dpois(.x, lambda = lambda()), ylim = c(0, dnorm(lambda(), lambda(), sd_())),
            xlab = "Número de Ocorrências", ylab = "Distribuição de Probabilidades",
            main = paste("Distribuicao Poisson:  lambda = ", sprintf("%.1f", lambda()), sep=""), discrete = TRUE)
        # gráfico da distribuição normal
        curve(dnorm(x, lambda(), sd_()), xlim = c(0, trunc(lambda() * 5)), main = "", xlab = "",
            ylab = "", yaxt = 'n', ylim = c(0, dnorm(lambda(), lambda(), sd_())), add = TRUE, col = "blue")
    })
}


ui <- fluidPage(
    titlePanel("Poisson x Normal"),
    
    sidebarLayout(sidebarPanel(
        sliderInput("lambda", label = "Lambda", min = 0.1, max = 100, value = 5)
),
    
    mainPanel(plotOutput("poisson_normal")))
)

shinyApp(ui = ui, server = server)