# applicação que mostra a relação entre o risco relativo e a razão de chances
# autor: Sergio Miranda Freire
#
#  License: Creative Commons: CC BY-SA
#

library(shiny)

#
server <- function(input, output) {

    razaoChancesSup <- reactive ({
        input$razaoChancesSup
    })

    riscoBasal <- reactive ({
        input$riscoBasal
    })
    
    razaoChancesSub <- reactive ({
        input$razaoChancesSub
    })
    
    output$oddsRatioSuper <- renderPlot({
        # linha correspondente ao valor selecionado da razão de chances
        curve((razaoChancesSup() - 1) * x, xlim = c(0, 100), ylim = c(0, 200), main = "RC > 1", xlab = "Risco Basal", ylab = "Sobre-estimativa (Porcentagem do RR)", col = "red", lwd = 3)
        #
        # outras linhas de referência
        # pi - abscissas onde o valor da razão de chances para a correspondente linha de referência será escrito 
        # rc - valores da razão de chances para as linhas de referência
        pi <- c(90, 90, 50, 26)
        rc <- c(1.5, 3, 5, 8)
        for (i in 1:length(rc)) {
            if (rc[i] != razaoChancesSup()) { # não irá traçar a linha de referência se o valor da razão de chances escolhido pelo usuário for igual ao da linha
                # linha de referência i
                curve((rc[i] - 1) * x, xlim = c(0, 100), ylim = c(0, 200), add = TRUE)
                # valor da razão de chances correspondente à linha de referência i
                text(pi[i], (rc[i] - 1) * pi[i] - 5, paste(sprintf("%.1f", rc[i])), pos = 4)
            }
        }
        # valor da sobre-estimativa em porcentagem
        y <- (razaoChancesSup() - 1) * riscoBasal()
        # valor correspondente do risco relativo correspondente à razão de chances selecionada
        rr <- razaoChancesSup() / (y/100 + 1)
        points(riscoBasal(), y, col = "blue", pch = 21, cex = 2.0, bg = "blue")
        text(riscoBasal() + .01, y - 5, paste("S = ", sprintf("%.1f", y), "% (RR = ", sprintf("%.2f", rr),")"), pos = 4, col = "blue")
    })
    
    output$oddsRatioSub <- renderPlot({
        # linha correspondente ao valor selecionado da razão de chances
        curve((1 - razaoChancesSub()) * x, xlim = c(0, 100), ylim = c(0, 90), main = "RC < 1", xlab = "Risco Basal", ylab = "Subestimativa (Porcentagem do RR)", col = "red", lwd = 3)
        #
        # outras linhas de referência
        # pi - abscissas onde o valor da razão de chances para a correspondente linha de referência será escrito 
        # rc - valores da razão de chances para as linhas de referência
        pi <- c(90, 90, 90, 90, 90)
        rc <- c(0.1, .3, .5, .7, .9)
        for (i in 1:length(rc)) {
            if (rc[i] != razaoChancesSub()) { # não irá traçar a linha de referência se o valor da razão de chances escolhido pelo usuário for igual ao da linha
                # linha de referência i
                curve((1 - rc[i]) * x, xlim = c(0, 100), ylim = c(0, 90), add = TRUE)
                # valor da razão de chances correspondente à linha de referência i
                text(pi[i], (1 - rc[i]) * pi[i] - 5, paste(sprintf("%.1f", rc[i])), pos = 4)
            }
        }
        # valor da sobre-estimativa em porcentagem
        y <- (1 - razaoChancesSub()) * riscoBasal()
        # valor correspondente do risco relativo correspondente à razão de chances selecionada
        rr <- razaoChancesSub() / (1 - y/100)
        points(riscoBasal(), y, col = "blue", pch = 21, cex = 2.0, bg = "blue")
        text(riscoBasal() + .01, y - 5, paste("S = ", sprintf("%.1f", y), "% (RR = ", sprintf("%.2f", rr),")"), pos = 4, col = "blue")
    })
    
}


#
ui <- fluidPage(# Application title
    titlePanel(expression("Risco Relativo x Razão de Chances")),
    
    # Sidebar with a slider input for the odds ratio
    sidebarLayout(
        sidebarPanel(
            sliderInput(
                "razaoChancesSup",
                expression("Razão de Chances > 1:"),
                min = 1,
                max = 20,
                value = 2,
                step = 0.5
            ),
            sliderInput(
                "razaoChancesSub",
                expression("Razão de Chances < 1:"),
                min = 0.05,
                max = 1,
                value = .5,
                step = 0.05
            ),
            sliderInput(
                "riscoBasal",
                "Risco Basal (Porcentagem):",
                min = 0.1,
                max = 100,
                value = 20,
                step = 0.05
            )
        ),
        
        # Show plots
        mainPanel(fluidRow(
            column(8, plotOutput("oddsRatioSuper")),
            column(8, plotOutput("oddsRatioSub"))
        ))
    ))


shinyApp(ui = ui, server = server)